# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/auction.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/auction/v1beta1/auction.proto',
  package='injective.auction.v1beta1',
  syntax='proto3',
  serialized_options=b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'injective/auction/v1beta1/auction.proto\x12\x19injective.auction.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"{\n\x06Params\x12\x16\n\x0e\x61uction_period\x18\x01 \x01(\x03\x12S\n\x1bmin_next_bid_increment_rate\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"s\n\x03\x42id\x12+\n\x06\x62idder\x18\x01 \x01(\tB\x1b\xea\xde\x1f\x06\x62idder\xf2\xde\x1f\ryaml:\"bidder\"\x12?\n\x06\x61mount\x18\x02 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\"j\n\x08\x45ventBid\x12\x0e\n\x06\x62idder\x18\x01 \x01(\t\x12?\n\x06\x61mount\x18\x02 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\x12\r\n\x05round\x18\x03 \x01(\x04\"t\n\x12\x45ventAuctionResult\x12\x0e\n\x06winner\x18\x01 \x01(\t\x12?\n\x06\x61mount\x18\x02 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\x12\r\n\x05round\x18\x03 \x01(\x04\"\x9d\x01\n\x11\x45ventAuctionStart\x12\r\n\x05round\x18\x01 \x01(\x04\x12\x18\n\x10\x65nding_timestamp\x18\x02 \x01(\x03\x12_\n\nnew_basket\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsBOZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.auction.v1beta1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='auction_period', full_name='injective.auction.v1beta1.Params.auction_period', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_next_bid_increment_rate', full_name='injective.auction.v1beta1.Params.min_next_bid_increment_rate', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=124,
  serialized_end=247,
)


_BID = _descriptor.Descriptor(
  name='Bid',
  full_name='injective.auction.v1beta1.Bid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bidder', full_name='injective.auction.v1beta1.Bid.bidder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\352\336\037\006bidder\362\336\037\ryaml:\"bidder\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.auction.v1beta1.Bid.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=249,
  serialized_end=364,
)


_EVENTBID = _descriptor.Descriptor(
  name='EventBid',
  full_name='injective.auction.v1beta1.EventBid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bidder', full_name='injective.auction.v1beta1.EventBid.bidder', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.auction.v1beta1.EventBid.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective.auction.v1beta1.EventBid.round', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=472,
)


_EVENTAUCTIONRESULT = _descriptor.Descriptor(
  name='EventAuctionResult',
  full_name='injective.auction.v1beta1.EventAuctionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='winner', full_name='injective.auction.v1beta1.EventAuctionResult.winner', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.auction.v1beta1.EventAuctionResult.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective.auction.v1beta1.EventAuctionResult.round', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=474,
  serialized_end=590,
)


_EVENTAUCTIONSTART = _descriptor.Descriptor(
  name='EventAuctionStart',
  full_name='injective.auction.v1beta1.EventAuctionStart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='round', full_name='injective.auction.v1beta1.EventAuctionStart.round', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ending_timestamp', full_name='injective.auction.v1beta1.EventAuctionStart.ending_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_basket', full_name='injective.auction.v1beta1.EventAuctionStart.new_basket', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=593,
  serialized_end=750,
)

_EVENTAUCTIONSTART.fields_by_name['new_basket'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['Bid'] = _BID
DESCRIPTOR.message_types_by_name['EventBid'] = _EVENTBID
DESCRIPTOR.message_types_by_name['EventAuctionResult'] = _EVENTAUCTIONRESULT
DESCRIPTOR.message_types_by_name['EventAuctionStart'] = _EVENTAUCTIONSTART
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.auction.v1beta1.auction_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

Bid = _reflection.GeneratedProtocolMessageType('Bid', (_message.Message,), {
  'DESCRIPTOR' : _BID,
  '__module__' : 'injective.auction.v1beta1.auction_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.Bid)
  })
_sym_db.RegisterMessage(Bid)

EventBid = _reflection.GeneratedProtocolMessageType('EventBid', (_message.Message,), {
  'DESCRIPTOR' : _EVENTBID,
  '__module__' : 'injective.auction.v1beta1.auction_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.EventBid)
  })
_sym_db.RegisterMessage(EventBid)

EventAuctionResult = _reflection.GeneratedProtocolMessageType('EventAuctionResult', (_message.Message,), {
  'DESCRIPTOR' : _EVENTAUCTIONRESULT,
  '__module__' : 'injective.auction.v1beta1.auction_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.EventAuctionResult)
  })
_sym_db.RegisterMessage(EventAuctionResult)

EventAuctionStart = _reflection.GeneratedProtocolMessageType('EventAuctionStart', (_message.Message,), {
  'DESCRIPTOR' : _EVENTAUCTIONSTART,
  '__module__' : 'injective.auction.v1beta1.auction_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.EventAuctionStart)
  })
_sym_db.RegisterMessage(EventAuctionStart)


DESCRIPTOR._options = None
_PARAMS.fields_by_name['min_next_bid_increment_rate']._options = None
_PARAMS._options = None
_BID.fields_by_name['bidder']._options = None
_BID.fields_by_name['amount']._options = None
_EVENTBID.fields_by_name['amount']._options = None
_EVENTAUCTIONRESULT.fields_by_name['amount']._options = None
_EVENTAUCTIONSTART.fields_by_name['new_basket']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/auction/v1beta1/tx.proto',
  package='injective.auction.v1beta1',
  syntax='proto3',
  serialized_options=b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"injective/auction/v1beta1/tx.proto\x12\x19injective.auction.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"f\n\x06MsgBid\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x33\n\nbid_amount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\r\n\x05round\x18\x03 \x01(\x04:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x10\n\x0eMsgBidResponse2Z\n\x03Msg\x12S\n\x03\x42id\x12!.injective.auction.v1beta1.MsgBid\x1a).injective.auction.v1beta1.MsgBidResponseBOZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_MSGBID = _descriptor.Descriptor(
  name='MsgBid',
  full_name='injective.auction.v1beta1.MsgBid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.auction.v1beta1.MsgBid.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bid_amount', full_name='injective.auction.v1beta1.MsgBid.bid_amount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='round', full_name='injective.auction.v1beta1.MsgBid.round', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=119,
  serialized_end=221,
)


_MSGBIDRESPONSE = _descriptor.Descriptor(
  name='MsgBidResponse',
  full_name='injective.auction.v1beta1.MsgBidResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=223,
  serialized_end=239,
)

_MSGBID.fields_by_name['bid_amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgBid'] = _MSGBID
DESCRIPTOR.message_types_by_name['MsgBidResponse'] = _MSGBIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgBid = _reflection.GeneratedProtocolMessageType('MsgBid', (_message.Message,), {
  'DESCRIPTOR' : _MSGBID,
  '__module__' : 'injective.auction.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.MsgBid)
  })
_sym_db.RegisterMessage(MsgBid)

MsgBidResponse = _reflection.GeneratedProtocolMessageType('MsgBidResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGBIDRESPONSE,
  '__module__' : 'injective.auction.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.auction.v1beta1.MsgBidResponse)
  })
_sym_db.RegisterMessage(MsgBidResponse)


DESCRIPTOR._options = None
_MSGBID.fields_by_name['bid_amount']._options = None
_MSGBID._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='injective.auction.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=241,
  serialized_end=331,
  methods=[
  _descriptor.MethodDescriptor(
    name='Bid',
    full_name='injective.auction.v1beta1.Msg.Bid',
    index=0,
    containing_service=None,
    input_type=_MSGBID,
    output_type=_MSGBIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.peggy.v1 import genesis_pb2 as injective_dot_peggy_dot_v1_dot_genesis__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from injective.peggy.v1 import msgs_pb2 as injective_dot_peggy_dot_v1_dot_msgs__pb2
from injective.peggy.v1 import pool_pb2 as injective_dot_peggy_dot_v1_dot_pool__pb2
from injective.peggy.v1 import batch_pb2 as injective_dot_peggy_dot_v1_dot_batch__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/query.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1einjective/peggy/v1/query.proto\x12\x12injective.peggy.v1\x1a injective/peggy/v1/genesis.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x1dinjective/peggy/v1/msgs.proto\x1a\x1dinjective/peggy/v1/pool.proto\x1a\x1einjective/peggy/v1/batch.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x14gogoproto/gogo.proto\"\x14\n\x12QueryParamsRequest\"G\n\x13QueryParamsResponse\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.ParamsB\x04\xc8\xde\x1f\x00\"\x1b\n\x19QueryCurrentValsetRequest\"H\n\x1aQueryCurrentValsetResponse\x12*\n\x06valset\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.Valset\"*\n\x19QueryValsetRequestRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\"H\n\x1aQueryValsetRequestResponse\x12*\n\x06valset\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.Valset\";\n\x19QueryValsetConfirmRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\"S\n\x1aQueryValsetConfirmResponse\x12\x35\n\x07\x63onfirm\x18\x01 \x01(\x0b\x32$.injective.peggy.v1.MsgValsetConfirm\"2\n!QueryValsetConfirmsByNonceRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\"\\\n\"QueryValsetConfirmsByNonceResponse\x12\x36\n\x08\x63onfirms\x18\x01 \x03(\x0b\x32$.injective.peggy.v1.MsgValsetConfirm\" \n\x1eQueryLastValsetRequestsRequest\"N\n\x1fQueryLastValsetRequestsResponse\x12+\n\x07valsets\x18\x01 \x03(\x0b\x32\x1a.injective.peggy.v1.Valset\"=\n*QueryLastPendingValsetRequestByAddrRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"Z\n+QueryLastPendingValsetRequestByAddrResponse\x12+\n\x07valsets\x18\x01 \x03(\x0b\x32\x1a.injective.peggy.v1.Valset\"\x16\n\x14QueryBatchFeeRequest\"I\n\x15QueryBatchFeeResponse\x12\x30\n\tbatchFees\x18\x01 \x03(\x0b\x32\x1d.injective.peggy.v1.BatchFees\"<\n)QueryLastPendingBatchRequestByAddrRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"`\n*QueryLastPendingBatchRequestByAddrResponse\x12\x32\n\x05\x62\x61tch\x18\x01 \x01(\x0b\x32#.injective.peggy.v1.OutgoingTxBatch\"\x1f\n\x1dQueryOutgoingTxBatchesRequest\"V\n\x1eQueryOutgoingTxBatchesResponse\x12\x34\n\x07\x62\x61tches\x18\x01 \x03(\x0b\x32#.injective.peggy.v1.OutgoingTxBatch\"J\n\x1fQueryBatchRequestByNonceRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\"V\n QueryBatchRequestByNonceResponse\x12\x32\n\x05\x62\x61tch\x18\x01 \x01(\x0b\x32#.injective.peggy.v1.OutgoingTxBatch\"D\n\x19QueryBatchConfirmsRequest\x12\r\n\x05nonce\x18\x01 \x01(\x04\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\"S\n\x1aQueryBatchConfirmsResponse\x12\x35\n\x08\x63onfirms\x18\x01 \x03(\x0b\x32#.injective.peggy.v1.MsgConfirmBatch\".\n\x1bQueryLastEventByAddrRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"\\\n\x1cQueryLastEventByAddrResponse\x12<\n\x10last_claim_event\x18\x01 \x01(\x0b\x32\".injective.peggy.v1.LastClaimEvent\")\n\x18QueryERC20ToDenomRequest\x12\r\n\x05\x65rc20\x18\x01 \x01(\t\"E\n\x19QueryERC20ToDenomResponse\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x19\n\x11\x63osmos_originated\x18\x02 \x01(\x08\")\n\x18QueryDenomToERC20Request\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\"E\n\x19QueryDenomToERC20Response\x12\r\n\x05\x65rc20\x18\x01 \x01(\t\x12\x19\n\x11\x63osmos_originated\x18\x02 \x01(\x08\"@\n#QueryDelegateKeysByValidatorAddress\x12\x19\n\x11validator_address\x18\x01 \x01(\t\"`\n+QueryDelegateKeysByValidatorAddressResponse\x12\x13\n\x0b\x65th_address\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"4\n\x1dQueryDelegateKeysByEthAddress\x12\x13\n\x0b\x65th_address\x18\x01 \x01(\t\"`\n%QueryDelegateKeysByEthAddressResponse\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"F\n&QueryDelegateKeysByOrchestratorAddress\x12\x1c\n\x14orchestrator_address\x18\x01 \x01(\t\"`\n.QueryDelegateKeysByOrchestratorAddressResponse\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x13\n\x0b\x65th_address\x18\x02 \x01(\t\"/\n\x15QueryPendingSendToEth\x12\x16\n\x0esender_address\x18\x01 \x01(\t\"\xaa\x01\n\x1dQueryPendingSendToEthResponse\x12\x44\n\x14transfers_in_batches\x18\x01 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTx\x12\x43\n\x13unbatched_transfers\x18\x02 \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTx\"\x19\n\x17QueryModuleStateRequest\"K\n\x18QueryModuleStateResponse\x12/\n\x05state\x18\x01 \x01(\x0b\x32 .injective.peggy.v1.GenesisState2\xb8\x19\n\x05Query\x12s\n\x06Params\x12&.injective.peggy.v1.QueryParamsRequest\x1a\'.injective.peggy.v1.QueryParamsResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/peggy/v1/params\x12\x90\x01\n\rCurrentValset\x12-.injective.peggy.v1.QueryCurrentValsetRequest\x1a..injective.peggy.v1.QueryCurrentValsetResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/valset/current\x12\x88\x01\n\rValsetRequest\x12-.injective.peggy.v1.QueryValsetRequestRequest\x1a..injective.peggy.v1.QueryValsetRequestResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/peggy/v1/valset\x12\x90\x01\n\rValsetConfirm\x12-.injective.peggy.v1.QueryValsetConfirmRequest\x1a..injective.peggy.v1.QueryValsetConfirmResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/valset/confirm\x12\xaa\x01\n\x15ValsetConfirmsByNonce\x12\x35.injective.peggy.v1.QueryValsetConfirmsByNonceRequest\x1a\x36.injective.peggy.v1.QueryValsetConfirmsByNonceResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/peggy/v1/confirms/{nonce}\x12\xa0\x01\n\x12LastValsetRequests\x12\x32.injective.peggy.v1.QueryLastValsetRequestsRequest\x1a\x33.injective.peggy.v1.QueryLastValsetRequestsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/peggy/v1/valset/requests\x12\xc0\x01\n\x1eLastPendingValsetRequestByAddr\x12>.injective.peggy.v1.QueryLastPendingValsetRequestByAddrRequest\x1a?.injective.peggy.v1.QueryLastPendingValsetRequestByAddrResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/peggy/v1/valset/last\x12\x9e\x01\n\x0fLastEventByAddr\x12/.injective.peggy.v1.QueryLastEventByAddrRequest\x1a\x30.injective.peggy.v1.QueryLastEventByAddrResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /peggy/v1/oracle/event/{address}\x12\x9a\x01\n\x13GetPendingSendToEth\x12).injective.peggy.v1.QueryPendingSendToEth\x1a\x31.injective.peggy.v1.QueryPendingSendToEthResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/peggy/v1/pending_send_to_eth\x12}\n\tBatchFees\x12(.injective.peggy.v1.QueryBatchFeeRequest\x1a).injective.peggy.v1.QueryBatchFeeResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/peggy/v1/batchfees\x12\x9e\x01\n\x11OutgoingTxBatches\x12\x31.injective.peggy.v1.QueryOutgoingTxBatchesRequest\x1a\x32.injective.peggy.v1.QueryOutgoingTxBatchesResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/peggy/v1/batch/outgoingtx\x12\xbc\x01\n\x1dLastPendingBatchRequestByAddr\x12=.injective.peggy.v1.QueryLastPendingBatchRequestByAddrRequest\x1a>.injective.peggy.v1.QueryLastPendingBatchRequestByAddrResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/peggy/v1/batch/last\x12\x99\x01\n\x13\x42\x61tchRequestByNonce\x12\x33.injective.peggy.v1.QueryBatchRequestByNonceRequest\x1a\x34.injective.peggy.v1.QueryBatchRequestByNonceResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/peggy/v1/batch\x12\x90\x01\n\rBatchConfirms\x12-.injective.peggy.v1.QueryBatchConfirmsRequest\x1a..injective.peggy.v1.QueryBatchConfirmsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/peggy/v1/batch/confirms\x12\x9f\x01\n\x0c\x45RC20ToDenom\x12,.injective.peggy.v1.QueryERC20ToDenomRequest\x1a-.injective.peggy.v1.QueryERC20ToDenomResponse\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/cosmos_originated/erc20_to_denom\x12\x9f\x01\n\x0c\x44\x65nomToERC20\x12,.injective.peggy.v1.QueryDenomToERC20Request\x1a-.injective.peggy.v1.QueryDenomToERC20Response\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/cosmos_originated/denom_to_erc20\x12\xc9\x01\n\x19GetDelegateKeyByValidator\x12\x37.injective.peggy.v1.QueryDelegateKeysByValidatorAddress\x1a?.injective.peggy.v1.QueryDelegateKeysByValidatorAddressResponse\"2\x82\xd3\xe4\x93\x02,\x12*/peggy/v1/query_delegate_keys_by_validator\x12\xb1\x01\n\x13GetDelegateKeyByEth\x12\x31.injective.peggy.v1.QueryDelegateKeysByEthAddress\x1a\x39.injective.peggy.v1.QueryDelegateKeysByEthAddressResponse\",\x82\xd3\xe4\x93\x02&\x12$/peggy/v1/query_delegate_keys_by_eth\x12\xd5\x01\n\x1cGetDelegateKeyByOrchestrator\x12:.injective.peggy.v1.QueryDelegateKeysByOrchestratorAddress\x1a\x42.injective.peggy.v1.QueryDelegateKeysByOrchestratorAddressResponse\"5\x82\xd3\xe4\x93\x02/\x12-/peggy/v1/query_delegate_keys_by_orchestrator\x12\x8d\x01\n\x10PeggyModuleState\x12+.injective.peggy.v1.QueryModuleStateRequest\x1a,.injective.peggy.v1.QueryModuleStateResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/peggy/v1/module_stateBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[injective_dot_peggy_dot_v1_dot_genesis__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_types__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_msgs__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_pool__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_batch__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_QUERYPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryParamsRequest',
  full_name='injective.peggy.v1.QueryParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=286,
)


_QUERYPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryParamsResponse',
  full_name='injective.peggy.v1.QueryParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.peggy.v1.QueryParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=359,
)


_QUERYCURRENTVALSETREQUEST = _descriptor.Descriptor(
  name='QueryCurrentValsetRequest',
  full_name='injective.peggy.v1.QueryCurrentValsetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=361,
  serialized_end=388,
)


_QUERYCURRENTVALSETRESPONSE = _descriptor.Descriptor(
  name='QueryCurrentValsetResponse',
  full_name='injective.peggy.v1.QueryCurrentValsetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valset', full_name='injective.peggy.v1.QueryCurrentValsetResponse.valset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=462,
)


_QUERYVALSETREQUESTREQUEST = _descriptor.Descriptor(
  name='QueryValsetRequestRequest',
  full_name='injective.peggy.v1.QueryValsetRequestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.QueryValsetRequestRequest.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=464,
  serialized_end=506,
)


_QUERYVALSETREQUESTRESPONSE = _descriptor.Descriptor(
  name='QueryValsetRequestResponse',
  full_name='injective.peggy.v1.QueryValsetRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valset', full_name='injective.peggy.v1.QueryValsetRequestResponse.valset', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=580,
)


_QUERYVALSETCONFIRMREQUEST = _descriptor.Descriptor(
  name='QueryValsetConfirmRequest',
  full_name='injective.peggy.v1.QueryValsetConfirmRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.QueryValsetConfirmRequest.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.peggy.v1.QueryValsetConfirmRequest.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=641,
)


_QUERYVALSETCONFIRMRESPONSE = _descriptor.Descriptor(
  name='QueryValsetConfirmResponse',
  full_name='injective.peggy.v1.QueryValsetConfirmResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='confirm', full_name='injective.peggy.v1.QueryValsetConfirmResponse.confirm', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=643,
  serialized_end=726,
)


_QUERYVALSETCONFIRMSBYNONCEREQUEST = _descriptor.Descriptor(
  name='QueryValsetConfirmsByNonceRequest',
  full_name='injective.peggy.v1.QueryValsetConfirmsByNonceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.QueryValsetConfirmsByNonceRequest.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=728,
  serialized_end=778,
)


_QUERYVALSETCONFIRMSBYNONCERESPONSE = _descriptor.Descriptor(
  name='QueryValsetConfirmsByNonceResponse',
  full_name='injective.peggy.v1.QueryValsetConfirmsByNonceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='confirms', full_name='injective.peggy.v1.QueryValsetConfirmsByNonceResponse.confirms', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=872,
)


_QUERYLASTVALSETREQUESTSREQUEST = _descriptor.Descriptor(
  name='QueryLastValsetRequestsRequest',
  full_name='injective.peggy.v1.QueryLastValsetRequestsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=874,
  serialized_end=906,
)


_QUERYLASTVALSETREQUESTSRESPONSE = _descriptor.Descriptor(
  name='QueryLastValsetRequestsResponse',
  full_name='injective.peggy.v1.QueryLastValsetRequestsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valsets', full_name='injective.peggy.v1.QueryLastValsetRequestsResponse.valsets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=908,
  serialized_end=986,
)


_QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST = _descriptor.Descriptor(
  name='QueryLastPendingValsetRequestByAddrRequest',
  full_name='injective.peggy.v1.QueryLastPendingValsetRequestByAddrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.peggy.v1.QueryLastPendingValsetRequestByAddrRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=988,
  serialized_end=1049,
)


_QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE = _descriptor.Descriptor(
  name='QueryLastPendingValsetRequestByAddrResponse',
  full_name='injective.peggy.v1.QueryLastPendingValsetRequestByAddrResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='valsets', full_name='injective.peggy.v1.QueryLastPendingValsetRequestByAddrResponse.valsets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1051,
  serialized_end=1141,
)


_QUERYBATCHFEEREQUEST = _descriptor.Descriptor(
  name='QueryBatchFeeRequest',
  full_name='injective.peggy.v1.QueryBatchFeeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1143,
  serialized_end=1165,
)


_QUERYBATCHFEERESPONSE = _descriptor.Descriptor(
  name='QueryBatchFeeResponse',
  full_name='injective.peggy.v1.QueryBatchFeeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batchFees', full_name='injective.peggy.v1.QueryBatchFeeResponse.batchFees', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1167,
  serialized_end=1240,
)


_QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST = _descriptor.Descriptor(
  name='QueryLastPendingBatchRequestByAddrRequest',
  full_name='injective.peggy.v1.QueryLastPendingBatchRequestByAddrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.peggy.v1.QueryLastPendingBatchRequestByAddrRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1242,
  serialized_end=1302,
)


_QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE = _descriptor.Descriptor(
  name='QueryLastPendingBatchRequestByAddrResponse',
  full_name='injective.peggy.v1.QueryLastPendingBatchRequestByAddrResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch', full_name='injective.peggy.v1.QueryLastPendingBatchRequestByAddrResponse.batch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1304,
  serialized_end=1400,
)


_QUERYOUTGOINGTXBATCHESREQUEST = _descriptor.Descriptor(
  name='QueryOutgoingTxBatchesRequest',
  full_name='injective.peggy.v1.QueryOutgoingTxBatchesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1402,
  serialized_end=1433,
)


_QUERYOUTGOINGTXBATCHESRESPONSE = _descriptor.Descriptor(
  name='QueryOutgoingTxBatchesResponse',
  full_name='injective.peggy.v1.QueryOutgoingTxBatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batches', full_name='injective.peggy.v1.QueryOutgoingTxBatchesResponse.batches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1435,
  serialized_end=1521,
)


_QUERYBATCHREQUESTBYNONCEREQUEST = _descriptor.Descriptor(
  name='QueryBatchRequestByNonceRequest',
  full_name='injective.peggy.v1.QueryBatchRequestByNonceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.QueryBatchRequestByNonceRequest.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_address', full_name='injective.peggy.v1.QueryBatchRequestByNonceRequest.contract_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1523,
  serialized_end=1597,
)


_QUERYBATCHREQUESTBYNONCERESPONSE = _descriptor.Descriptor(
  name='QueryBatchRequestByNonceResponse',
  full_name='injective.peggy.v1.QueryBatchRequestByNonceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='batch', full_name='injective.peggy.v1.QueryBatchRequestByNonceResponse.batch', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1599,
  serialized_end=1685,
)


_QUERYBATCHCONFIRMSREQUEST = _descriptor.Descriptor(
  name='QueryBatchConfirmsRequest',
  full_name='injective.peggy.v1.QueryBatchConfirmsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.peggy.v1.QueryBatchConfirmsRequest.nonce', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_address', full_name='injective.peggy.v1.QueryBatchConfirmsRequest.contract_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1687,
  serialized_end=1755,
)


_QUERYBATCHCONFIRMSRESPONSE = _descriptor.Descriptor(
  name='QueryBatchConfirmsResponse',
  full_name='injective.peggy.v1.QueryBatchConfirmsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='confirms', full_name='injective.peggy.v1.QueryBatchConfirmsResponse.confirms', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1757,
  serialized_end=1840,
)


_QUERYLASTEVENTBYADDRREQUEST = _descriptor.Descriptor(
  name='QueryLastEventByAddrRequest',
  full_name='injective.peggy.v1.QueryLastEventByAddrRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.peggy.v1.QueryLastEventByAddrRequest.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1842,
  serialized_end=1888,
)


_QUERYLASTEVENTBYADDRRESPONSE = _descriptor.Descriptor(
  name='QueryLastEventByAddrResponse',
  full_name='injective.peggy.v1.QueryLastEventByAddrResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_claim_event', full_name='injective.peggy.v1.QueryLastEventByAddrResponse.last_claim_event', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1890,
  serialized_end=1982,
)


_QUERYERC20TODENOMREQUEST = _descriptor.Descriptor(
  name='QueryERC20ToDenomRequest',
  full_name='injective.peggy.v1.QueryERC20ToDenomRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='erc20', full_name='injective.peggy.v1.QueryERC20ToDenomRequest.erc20', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1984,
  serialized_end=2025,
)


_QUERYERC20TODENOMRESPONSE = _descriptor.Descriptor(
  name='QueryERC20ToDenomResponse',
  full_name='injective.peggy.v1.QueryERC20ToDenomResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.peggy.v1.QueryERC20ToDenomResponse.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_originated', full_name='injective.peggy.v1.QueryERC20ToDenomResponse.cosmos_originated', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2027,
  serialized_end=2096,
)


_QUERYDENOMTOERC20REQUEST = _descriptor.Descriptor(
  name='QueryDenomToERC20Request',
  full_name='injective.peggy.v1.QueryDenomToERC20Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.peggy.v1.QueryDenomToERC20Request.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2098,
  serialized_end=2139,
)


_QUERYDENOMTOERC20RESPONSE = _descriptor.Descriptor(
  name='QueryDenomToERC20Response',
  full_name='injective.peggy.v1.QueryDenomToERC20Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='erc20', full_name='injective.peggy.v1.QueryDenomToERC20Response.erc20', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_originated', full_name='injective.peggy.v1.QueryDenomToERC20Response.cosmos_originated', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2141,
  serialized_end=2210,
)


_QUERYDELEGATEKEYSBYVALIDATORADDRESS = _descriptor.Descriptor(
  name='QueryDelegateKeysByValidatorAddress',
  full_name='injective.peggy.v1.QueryDelegateKeysByValidatorAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='injective.peggy.v1.QueryDelegateKeysByValidatorAddress.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2212,
  serialized_end=2276,
)


_QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE = _descriptor.Descriptor(
  name='QueryDelegateKeysByValidatorAddressResponse',
  full_name='injective.peggy.v1.QueryDelegateKeysByValidatorAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eth_address', full_name='injective.peggy.v1.QueryDelegateKeysByValidatorAddressResponse.eth_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.QueryDelegateKeysByValidatorAddressResponse.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2278,
  serialized_end=2374,
)


_QUERYDELEGATEKEYSBYETHADDRESS = _descriptor.Descriptor(
  name='QueryDelegateKeysByEthAddress',
  full_name='injective.peggy.v1.QueryDelegateKeysByEthAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eth_address', full_name='injective.peggy.v1.QueryDelegateKeysByEthAddress.eth_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2376,
  serialized_end=2428,
)


_QUERYDELEGATEKEYSBYETHADDRESSRESPONSE = _descriptor.Descriptor(
  name='QueryDelegateKeysByEthAddressResponse',
  full_name='injective.peggy.v1.QueryDelegateKeysByEthAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='injective.peggy.v1.QueryDelegateKeysByEthAddressResponse.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.QueryDelegateKeysByEthAddressResponse.orchestrator_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2430,
  serialized_end=2526,
)


_QUERYDELEGATEKEYSBYORCHESTRATORADDRESS = _descriptor.Descriptor(
  name='QueryDelegateKeysByOrchestratorAddress',
  full_name='injective.peggy.v1.QueryDelegateKeysByOrchestratorAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orchestrator_address', full_name='injective.peggy.v1.QueryDelegateKeysByOrchestratorAddress.orchestrator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2528,
  serialized_end=2598,
)


_QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE = _descriptor.Descriptor(
  name='QueryDelegateKeysByOrchestratorAddressResponse',
  full_name='injective.peggy.v1.QueryDelegateKeysByOrchestratorAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_address', full_name='injective.peggy.v1.QueryDelegateKeysByOrchestratorAddressResponse.validator_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='eth_address', full_name='injective.peggy.v1.QueryDelegateKeysByOrchestratorAddressResponse.eth_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2600,
  serialized_end=2696,
)


_QUERYPENDINGSENDTOETH = _descriptor.Descriptor(
  name='QueryPendingSendToEth',
  full_name='injective.peggy.v1.QueryPendingSendToEth',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender_address', full_name='injective.peggy.v1.QueryPendingSendToEth.sender_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2698,
  serialized_end=2745,
)


_QUERYPENDINGSENDTOETHRESPONSE = _descriptor.Descriptor(
  name='QueryPendingSendToEthResponse',
  full_name='injective.peggy.v1.QueryPendingSendToEthResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfers_in_batches', full_name='injective.peggy.v1.QueryPendingSendToEthResponse.transfers_in_batches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unbatched_transfers', full_name='injective.peggy.v1.QueryPendingSendToEthResponse.unbatched_transfers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2748,
  serialized_end=2918,
)


_QUERYMODULESTATEREQUEST = _descriptor.Descriptor(
  name='QueryModuleStateRequest',
  full_name='injective.peggy.v1.QueryModuleStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2920,
  serialized_end=2945,
)


_QUERYMODULESTATERESPONSE = _descriptor.Descriptor(
  name='QueryModuleStateResponse',
  full_name='injective.peggy.v1.QueryModuleStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.peggy.v1.QueryModuleStateResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2947,
  serialized_end=3022,
)

_QUERYPARAMSRESPONSE.fields_by_name['params'].message_type = injective_dot_peggy_dot_v1_dot_genesis__pb2._PARAMS
_QUERYCURRENTVALSETRESPONSE.fields_by_name['valset'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._VALSET
_QUERYVALSETREQUESTRESPONSE.fields_by_name['valset'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._VALSET
_QUERYVALSETCONFIRMRESPONSE.fields_by_name['confirm'].message_type = injective_dot_peggy_dot_v1_dot_msgs__pb2._MSGVALSETCONFIRM
_QUERYVALSETCONFIRMSBYNONCERESPONSE.fields_by_name['confirms'].message_type = injective_dot_peggy_dot_v1_dot_msgs__pb2._MSGVALSETCONFIRM
_QUERYLASTVALSETREQUESTSRESPONSE.fields_by_name['valsets'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._VALSET
_QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE.fields_by_name['valsets'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._VALSET
_QUERYBATCHFEERESPONSE.fields_by_name['batchFees'].message_type = injective_dot_peggy_dot_v1_dot_pool__pb2._BATCHFEES
_QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE.fields_by_name['batch'].message_type = injective_dot_peggy_dot_v1_dot_batch__pb2._OUTGOINGTXBATCH
_QUERYOUTGOINGTXBATCHESRESPONSE.fields_by_name['batches'].message_type = injective_dot_peggy_dot_v1_dot_batch__pb2._OUTGOINGTXBATCH
_QUERYBATCHREQUESTBYNONCERESPONSE.fields_by_name['batch'].message_type = injective_dot_peggy_dot_v1_dot_batch__pb2._OUTGOINGTXBATCH
_QUERYBATCHCONFIRMSRESPONSE.fields_by_name['confirms'].message_type = injective_dot_peggy_dot_v1_dot_msgs__pb2._MSGCONFIRMBATCH
_QUERYLASTEVENTBYADDRRESPONSE.fields_by_name['last_claim_event'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._LASTCLAIMEVENT
_QUERYPENDINGSENDTOETHRESPONSE.fields_by_name['transfers_in_batches'].message_type = injective_dot_peggy_dot_v1_dot_batch__pb2._OUTGOINGTRANSFERTX
_QUERYPENDINGSENDTOETHRESPONSE.fields_by_name['unbatched_transfers'].message_type = injective_dot_peggy_dot_v1_dot_batch__pb2._OUTGOINGTRANSFERTX
_QUERYMODULESTATERESPONSE.fields_by_name['state'].message_type = injective_dot_peggy_dot_v1_dot_genesis__pb2._GENESISSTATE
DESCRIPTOR.message_types_by_name['QueryParamsRequest'] = _QUERYPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryParamsResponse'] = _QUERYPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryCurrentValsetRequest'] = _QUERYCURRENTVALSETREQUEST
DESCRIPTOR.message_types_by_name['QueryCurrentValsetResponse'] = _QUERYCURRENTVALSETRESPONSE
DESCRIPTOR.message_types_by_name['QueryValsetRequestRequest'] = _QUERYVALSETREQUESTREQUEST
DESCRIPTOR.message_types_by_name['QueryValsetRequestResponse'] = _QUERYVALSETREQUESTRESPONSE
DESCRIPTOR.message_types_by_name['QueryValsetConfirmRequest'] = _QUERYVALSETCONFIRMREQUEST
DESCRIPTOR.message_types_by_name['QueryValsetConfirmResponse'] = _QUERYVALSETCONFIRMRESPONSE
DESCRIPTOR.message_types_by_name['QueryValsetConfirmsByNonceRequest'] = _QUERYVALSETCONFIRMSBYNONCEREQUEST
DESCRIPTOR.message_types_by_name['QueryValsetConfirmsByNonceResponse'] = _QUERYVALSETCONFIRMSBYNONCERESPONSE
DESCRIPTOR.message_types_by_name['QueryLastValsetRequestsRequest'] = _QUERYLASTVALSETREQUESTSREQUEST
DESCRIPTOR.message_types_by_name['QueryLastValsetRequestsResponse'] = _QUERYLASTVALSETREQUESTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryLastPendingValsetRequestByAddrRequest'] = _QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST
DESCRIPTOR.message_types_by_name['QueryLastPendingValsetRequestByAddrResponse'] = _QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE
DESCRIPTOR.message_types_by_name['QueryBatchFeeRequest'] = _QUERYBATCHFEEREQUEST
DESCRIPTOR.message_types_by_name['QueryBatchFeeResponse'] = _QUERYBATCHFEERESPONSE
DESCRIPTOR.message_types_by_name['QueryLastPendingBatchRequestByAddrRequest'] = _QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST
DESCRIPTOR.message_types_by_name['QueryLastPendingBatchRequestByAddrResponse'] = _QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE
DESCRIPTOR.message_types_by_name['QueryOutgoingTxBatchesRequest'] = _QUERYOUTGOINGTXBATCHESREQUEST
DESCRIPTOR.message_types_by_name['QueryOutgoingTxBatchesResponse'] = _QUERYOUTGOINGTXBATCHESRESPONSE
DESCRIPTOR.message_types_by_name['QueryBatchRequestByNonceRequest'] = _QUERYBATCHREQUESTBYNONCEREQUEST
DESCRIPTOR.message_types_by_name['QueryBatchRequestByNonceResponse'] = _QUERYBATCHREQUESTBYNONCERESPONSE
DESCRIPTOR.message_types_by_name['QueryBatchConfirmsRequest'] = _QUERYBATCHCONFIRMSREQUEST
DESCRIPTOR.message_types_by_name['QueryBatchConfirmsResponse'] = _QUERYBATCHCONFIRMSRESPONSE
DESCRIPTOR.message_types_by_name['QueryLastEventByAddrRequest'] = _QUERYLASTEVENTBYADDRREQUEST
DESCRIPTOR.message_types_by_name['QueryLastEventByAddrResponse'] = _QUERYLASTEVENTBYADDRRESPONSE
DESCRIPTOR.message_types_by_name['QueryERC20ToDenomRequest'] = _QUERYERC20TODENOMREQUEST
DESCRIPTOR.message_types_by_name['QueryERC20ToDenomResponse'] = _QUERYERC20TODENOMRESPONSE
DESCRIPTOR.message_types_by_name['QueryDenomToERC20Request'] = _QUERYDENOMTOERC20REQUEST
DESCRIPTOR.message_types_by_name['QueryDenomToERC20Response'] = _QUERYDENOMTOERC20RESPONSE
DESCRIPTOR.message_types_by_name['QueryDelegateKeysByValidatorAddress'] = _QUERYDELEGATEKEYSBYVALIDATORADDRESS
DESCRIPTOR.message_types_by_name['QueryDelegateKeysByValidatorAddressResponse'] = _QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDelegateKeysByEthAddress'] = _QUERYDELEGATEKEYSBYETHADDRESS
DESCRIPTOR.message_types_by_name['QueryDelegateKeysByEthAddressResponse'] = _QUERYDELEGATEKEYSBYETHADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDelegateKeysByOrchestratorAddress'] = _QUERYDELEGATEKEYSBYORCHESTRATORADDRESS
DESCRIPTOR.message_types_by_name['QueryDelegateKeysByOrchestratorAddressResponse'] = _QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['QueryPendingSendToEth'] = _QUERYPENDINGSENDTOETH
DESCRIPTOR.message_types_by_name['QueryPendingSendToEthResponse'] = _QUERYPENDINGSENDTOETHRESPONSE
DESCRIPTOR.message_types_by_name['QueryModuleStateRequest'] = _QUERYMODULESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryModuleStateResponse'] = _QUERYMODULESTATERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

QueryCurrentValsetRequest = _reflection.GeneratedProtocolMessageType('QueryCurrentValsetRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCURRENTVALSETREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryCurrentValsetRequest)
  })
_sym_db.RegisterMessage(QueryCurrentValsetRequest)

QueryCurrentValsetResponse = _reflection.GeneratedProtocolMessageType('QueryCurrentValsetResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCURRENTVALSETRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryCurrentValsetResponse)
  })
_sym_db.RegisterMessage(QueryCurrentValsetResponse)

QueryValsetRequestRequest = _reflection.GeneratedProtocolMessageType('QueryValsetRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALSETREQUESTREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryValsetRequestRequest)
  })
_sym_db.RegisterMessage(QueryValsetRequestRequest)

QueryValsetRequestResponse = _reflection.GeneratedProtocolMessageType('QueryValsetRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALSETREQUESTRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryValsetRequestResponse)
  })
_sym_db.RegisterMessage(QueryValsetRequestResponse)

QueryValsetConfirmRequest = _reflection.GeneratedProtocolMessageType('QueryValsetConfirmRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALSETCONFIRMREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryValsetConfirmRequest)
  })
_sym_db.RegisterMessage(QueryValsetConfirmRequest)

QueryValsetConfirmResponse = _reflection.GeneratedProtocolMessageType('QueryValsetConfirmResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALSETCONFIRMRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryValsetConfirmResponse)
  })
_sym_db.RegisterMessage(QueryValsetConfirmResponse)

QueryValsetConfirmsByNonceRequest = _reflection.GeneratedProtocolMessageType('QueryValsetConfirmsByNonceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALSETCONFIRMSBYNONCEREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryValsetConfirmsByNonceRequest)
  })
_sym_db.RegisterMessage(QueryValsetConfirmsByNonceRequest)

QueryValsetConfirmsByNonceResponse = _reflection.GeneratedProtocolMessageType('QueryValsetConfirmsByNonceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVALSETCONFIRMSBYNONCERESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryValsetConfirmsByNonceResponse)
  })
_sym_db.RegisterMessage(QueryValsetConfirmsByNonceResponse)

QueryLastValsetRequestsRequest = _reflection.GeneratedProtocolMessageType('QueryLastValsetRequestsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTVALSETREQUESTSREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryLastValsetRequestsRequest)
  })
_sym_db.RegisterMessage(QueryLastValsetRequestsRequest)

QueryLastValsetRequestsResponse = _reflection.GeneratedProtocolMessageType('QueryLastValsetRequestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTVALSETREQUESTSRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryLastValsetRequestsResponse)
  })
_sym_db.RegisterMessage(QueryLastValsetRequestsResponse)

QueryLastPendingValsetRequestByAddrRequest = _reflection.GeneratedProtocolMessageType('QueryLastPendingValsetRequestByAddrRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryLastPendingValsetRequestByAddrRequest)
  })
_sym_db.RegisterMessage(QueryLastPendingValsetRequestByAddrRequest)

QueryLastPendingValsetRequestByAddrResponse = _reflection.GeneratedProtocolMessageType('QueryLastPendingValsetRequestByAddrResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryLastPendingValsetRequestByAddrResponse)
  })
_sym_db.RegisterMessage(QueryLastPendingValsetRequestByAddrResponse)

QueryBatchFeeRequest = _reflection.GeneratedProtocolMessageType('QueryBatchFeeRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBATCHFEEREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryBatchFeeRequest)
  })
_sym_db.RegisterMessage(QueryBatchFeeRequest)

QueryBatchFeeResponse = _reflection.GeneratedProtocolMessageType('QueryBatchFeeResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBATCHFEERESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryBatchFeeResponse)
  })
_sym_db.RegisterMessage(QueryBatchFeeResponse)

QueryLastPendingBatchRequestByAddrRequest = _reflection.GeneratedProtocolMessageType('QueryLastPendingBatchRequestByAddrRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryLastPendingBatchRequestByAddrRequest)
  })
_sym_db.RegisterMessage(QueryLastPendingBatchRequestByAddrRequest)

QueryLastPendingBatchRequestByAddrResponse = _reflection.GeneratedProtocolMessageType('QueryLastPendingBatchRequestByAddrResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryLastPendingBatchRequestByAddrResponse)
  })
_sym_db.RegisterMessage(QueryLastPendingBatchRequestByAddrResponse)

QueryOutgoingTxBatchesRequest = _reflection.GeneratedProtocolMessageType('QueryOutgoingTxBatchesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOUTGOINGTXBATCHESREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryOutgoingTxBatchesRequest)
  })
_sym_db.RegisterMessage(QueryOutgoingTxBatchesRequest)

QueryOutgoingTxBatchesResponse = _reflection.GeneratedProtocolMessageType('QueryOutgoingTxBatchesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOUTGOINGTXBATCHESRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryOutgoingTxBatchesResponse)
  })
_sym_db.RegisterMessage(QueryOutgoingTxBatchesResponse)

QueryBatchRequestByNonceRequest = _reflection.GeneratedProtocolMessageType('QueryBatchRequestByNonceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBATCHREQUESTBYNONCEREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryBatchRequestByNonceRequest)
  })
_sym_db.RegisterMessage(QueryBatchRequestByNonceRequest)

QueryBatchRequestByNonceResponse = _reflection.GeneratedProtocolMessageType('QueryBatchRequestByNonceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBATCHREQUESTBYNONCERESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryBatchRequestByNonceResponse)
  })
_sym_db.RegisterMessage(QueryBatchRequestByNonceResponse)

QueryBatchConfirmsRequest = _reflection.GeneratedProtocolMessageType('QueryBatchConfirmsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBATCHCONFIRMSREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryBatchConfirmsRequest)
  })
_sym_db.RegisterMessage(QueryBatchConfirmsRequest)

QueryBatchConfirmsResponse = _reflection.GeneratedProtocolMessageType('QueryBatchConfirmsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBATCHCONFIRMSRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryBatchConfirmsResponse)
  })
_sym_db.RegisterMessage(QueryBatchConfirmsResponse)

QueryLastEventByAddrRequest = _reflection.GeneratedProtocolMessageType('QueryLastEventByAddrRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTEVENTBYADDRREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryLastEventByAddrRequest)
  })
_sym_db.RegisterMessage(QueryLastEventByAddrRequest)

QueryLastEventByAddrResponse = _reflection.GeneratedProtocolMessageType('QueryLastEventByAddrResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYLASTEVENTBYADDRRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryLastEventByAddrResponse)
  })
_sym_db.RegisterMessage(QueryLastEventByAddrResponse)

QueryERC20ToDenomRequest = _reflection.GeneratedProtocolMessageType('QueryERC20ToDenomRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYERC20TODENOMREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryERC20ToDenomRequest)
  })
_sym_db.RegisterMessage(QueryERC20ToDenomRequest)

QueryERC20ToDenomResponse = _reflection.GeneratedProtocolMessageType('QueryERC20ToDenomResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYERC20TODENOMRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryERC20ToDenomResponse)
  })
_sym_db.RegisterMessage(QueryERC20ToDenomResponse)

QueryDenomToERC20Request = _reflection.GeneratedProtocolMessageType('QueryDenomToERC20Request', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDENOMTOERC20REQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryDenomToERC20Request)
  })
_sym_db.RegisterMessage(QueryDenomToERC20Request)

QueryDenomToERC20Response = _reflection.GeneratedProtocolMessageType('QueryDenomToERC20Response', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDENOMTOERC20RESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryDenomToERC20Response)
  })
_sym_db.RegisterMessage(QueryDenomToERC20Response)

QueryDelegateKeysByValidatorAddress = _reflection.GeneratedProtocolMessageType('QueryDelegateKeysByValidatorAddress', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATEKEYSBYVALIDATORADDRESS,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryDelegateKeysByValidatorAddress)
  })
_sym_db.RegisterMessage(QueryDelegateKeysByValidatorAddress)

QueryDelegateKeysByValidatorAddressResponse = _reflection.GeneratedProtocolMessageType('QueryDelegateKeysByValidatorAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryDelegateKeysByValidatorAddressResponse)
  })
_sym_db.RegisterMessage(QueryDelegateKeysByValidatorAddressResponse)

QueryDelegateKeysByEthAddress = _reflection.GeneratedProtocolMessageType('QueryDelegateKeysByEthAddress', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATEKEYSBYETHADDRESS,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryDelegateKeysByEthAddress)
  })
_sym_db.RegisterMessage(QueryDelegateKeysByEthAddress)

QueryDelegateKeysByEthAddressResponse = _reflection.GeneratedProtocolMessageType('QueryDelegateKeysByEthAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATEKEYSBYETHADDRESSRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryDelegateKeysByEthAddressResponse)
  })
_sym_db.RegisterMessage(QueryDelegateKeysByEthAddressResponse)

QueryDelegateKeysByOrchestratorAddress = _reflection.GeneratedProtocolMessageType('QueryDelegateKeysByOrchestratorAddress', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATEKEYSBYORCHESTRATORADDRESS,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryDelegateKeysByOrchestratorAddress)
  })
_sym_db.RegisterMessage(QueryDelegateKeysByOrchestratorAddress)

QueryDelegateKeysByOrchestratorAddressResponse = _reflection.GeneratedProtocolMessageType('QueryDelegateKeysByOrchestratorAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryDelegateKeysByOrchestratorAddressResponse)
  })
_sym_db.RegisterMessage(QueryDelegateKeysByOrchestratorAddressResponse)

QueryPendingSendToEth = _reflection.GeneratedProtocolMessageType('QueryPendingSendToEth', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPENDINGSENDTOETH,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryPendingSendToEth)
  })
_sym_db.RegisterMessage(QueryPendingSendToEth)

QueryPendingSendToEthResponse = _reflection.GeneratedProtocolMessageType('QueryPendingSendToEthResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPENDINGSENDTOETHRESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryPendingSendToEthResponse)
  })
_sym_db.RegisterMessage(QueryPendingSendToEthResponse)

QueryModuleStateRequest = _reflection.GeneratedProtocolMessageType('QueryModuleStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATEREQUEST,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryModuleStateRequest)
  })
_sym_db.RegisterMessage(QueryModuleStateRequest)

QueryModuleStateResponse = _reflection.GeneratedProtocolMessageType('QueryModuleStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATERESPONSE,
  '__module__' : 'injective.peggy.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.QueryModuleStateResponse)
  })
_sym_db.RegisterMessage(QueryModuleStateResponse)


DESCRIPTOR._options = None
_QUERYPARAMSRESPONSE.fields_by_name['params']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='injective.peggy.v1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3025,
  serialized_end=6281,
  methods=[
  _descriptor.MethodDescriptor(
    name='Params',
    full_name='injective.peggy.v1.Query.Params',
    index=0,
    containing_service=None,
    input_type=_QUERYPARAMSREQUEST,
    output_type=_QUERYPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/peggy/v1/params',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CurrentValset',
    full_name='injective.peggy.v1.Query.CurrentValset',
    index=1,
    containing_service=None,
    input_type=_QUERYCURRENTVALSETREQUEST,
    output_type=_QUERYCURRENTVALSETRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\022\030/peggy/v1/valset/current',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValsetRequest',
    full_name='injective.peggy.v1.Query.ValsetRequest',
    index=2,
    containing_service=None,
    input_type=_QUERYVALSETREQUESTREQUEST,
    output_type=_QUERYVALSETREQUESTRESPONSE,
    serialized_options=b'\202\323\344\223\002\022\022\020/peggy/v1/valset',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValsetConfirm',
    full_name='injective.peggy.v1.Query.ValsetConfirm',
    index=3,
    containing_service=None,
    input_type=_QUERYVALSETCONFIRMREQUEST,
    output_type=_QUERYVALSETCONFIRMRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\022\030/peggy/v1/valset/confirm',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ValsetConfirmsByNonce',
    full_name='injective.peggy.v1.Query.ValsetConfirmsByNonce',
    index=4,
    containing_service=None,
    input_type=_QUERYVALSETCONFIRMSBYNONCEREQUEST,
    output_type=_QUERYVALSETCONFIRMSBYNONCERESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/peggy/v1/confirms/{nonce}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LastValsetRequests',
    full_name='injective.peggy.v1.Query.LastValsetRequests',
    index=5,
    containing_service=None,
    input_type=_QUERYLASTVALSETREQUESTSREQUEST,
    output_type=_QUERYLASTVALSETREQUESTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/peggy/v1/valset/requests',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LastPendingValsetRequestByAddr',
    full_name='injective.peggy.v1.Query.LastPendingValsetRequestByAddr',
    index=6,
    containing_service=None,
    input_type=_QUERYLASTPENDINGVALSETREQUESTBYADDRREQUEST,
    output_type=_QUERYLASTPENDINGVALSETREQUESTBYADDRRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/peggy/v1/valset/last',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LastEventByAddr',
    full_name='injective.peggy.v1.Query.LastEventByAddr',
    index=7,
    containing_service=None,
    input_type=_QUERYLASTEVENTBYADDRREQUEST,
    output_type=_QUERYLASTEVENTBYADDRRESPONSE,
    serialized_options=b'\202\323\344\223\002\"\022 /peggy/v1/oracle/event/{address}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetPendingSendToEth',
    full_name='injective.peggy.v1.Query.GetPendingSendToEth',
    index=8,
    containing_service=None,
    input_type=_QUERYPENDINGSENDTOETH,
    output_type=_QUERYPENDINGSENDTOETHRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/peggy/v1/pending_send_to_eth',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchFees',
    full_name='injective.peggy.v1.Query.BatchFees',
    index=9,
    containing_service=None,
    input_type=_QUERYBATCHFEEREQUEST,
    output_type=_QUERYBATCHFEERESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/peggy/v1/batchfees',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OutgoingTxBatches',
    full_name='injective.peggy.v1.Query.OutgoingTxBatches',
    index=10,
    containing_service=None,
    input_type=_QUERYOUTGOINGTXBATCHESREQUEST,
    output_type=_QUERYOUTGOINGTXBATCHESRESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/peggy/v1/batch/outgoingtx',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LastPendingBatchRequestByAddr',
    full_name='injective.peggy.v1.Query.LastPendingBatchRequestByAddr',
    index=11,
    containing_service=None,
    input_type=_QUERYLASTPENDINGBATCHREQUESTBYADDRREQUEST,
    output_type=_QUERYLASTPENDINGBATCHREQUESTBYADDRRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\022\024/peggy/v1/batch/last',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchRequestByNonce',
    full_name='injective.peggy.v1.Query.BatchRequestByNonce',
    index=12,
    containing_service=None,
    input_type=_QUERYBATCHREQUESTBYNONCEREQUEST,
    output_type=_QUERYBATCHREQUESTBYNONCERESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/peggy/v1/batch',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BatchConfirms',
    full_name='injective.peggy.v1.Query.BatchConfirms',
    index=13,
    containing_service=None,
    input_type=_QUERYBATCHCONFIRMSREQUEST,
    output_type=_QUERYBATCHCONFIRMSRESPONSE,
    serialized_options=b'\202\323\344\223\002\032\022\030/peggy/v1/batch/confirms',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ERC20ToDenom',
    full_name='injective.peggy.v1.Query.ERC20ToDenom',
    index=14,
    containing_service=None,
    input_type=_QUERYERC20TODENOMREQUEST,
    output_type=_QUERYERC20TODENOMRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/peggy/v1/cosmos_originated/erc20_to_denom',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DenomToERC20',
    full_name='injective.peggy.v1.Query.DenomToERC20',
    index=15,
    containing_service=None,
    input_type=_QUERYDENOMTOERC20REQUEST,
    output_type=_QUERYDENOMTOERC20RESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/peggy/v1/cosmos_originated/denom_to_erc20',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDelegateKeyByValidator',
    full_name='injective.peggy.v1.Query.GetDelegateKeyByValidator',
    index=16,
    containing_service=None,
    input_type=_QUERYDELEGATEKEYSBYVALIDATORADDRESS,
    output_type=_QUERYDELEGATEKEYSBYVALIDATORADDRESSRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/peggy/v1/query_delegate_keys_by_validator',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDelegateKeyByEth',
    full_name='injective.peggy.v1.Query.GetDelegateKeyByEth',
    index=17,
    containing_service=None,
    input_type=_QUERYDELEGATEKEYSBYETHADDRESS,
    output_type=_QUERYDELEGATEKEYSBYETHADDRESSRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/peggy/v1/query_delegate_keys_by_eth',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDelegateKeyByOrchestrator',
    full_name='injective.peggy.v1.Query.GetDelegateKeyByOrchestrator',
    index=18,
    containing_service=None,
    input_type=_QUERYDELEGATEKEYSBYORCHESTRATORADDRESS,
    output_type=_QUERYDELEGATEKEYSBYORCHESTRATORADDRESSRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/peggy/v1/query_delegate_keys_by_orchestrator',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PeggyModuleState',
    full_name='injective.peggy.v1.Query.PeggyModuleState',
    index=19,
    containing_service=None,
    input_type=_QUERYMODULESTATEREQUEST,
    output_type=_QUERYMODULESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/peggy/v1/module_state',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/p2p/pex.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from tendermint.p2p import types_pb2 as tendermint_dot_p2p_dot_types__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/p2p/pex.proto',
  package='tendermint.p2p',
  syntax='proto3',
  serialized_options=b'Z5github.com/tendermint/tendermint/proto/tendermint/p2p',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x18tendermint/p2p/pex.proto\x12\x0etendermint.p2p\x1a\x1atendermint/p2p/types.proto\x1a\x14gogoproto/gogo.proto\"\x0c\n\nPexRequest\";\n\x08PexAddrs\x12/\n\x05\x61\x64\x64rs\x18\x01 \x03(\x0b\x32\x1a.tendermint.p2p.NetAddressB\x04\xc8\xde\x1f\x00\"r\n\x07Message\x12\x31\n\x0bpex_request\x18\x01 \x01(\x0b\x32\x1a.tendermint.p2p.PexRequestH\x00\x12-\n\tpex_addrs\x18\x02 \x01(\x0b\x32\x18.tendermint.p2p.PexAddrsH\x00\x42\x05\n\x03sumB7Z5github.com/tendermint/tendermint/proto/tendermint/p2pb\x06proto3'
  ,
  dependencies=[tendermint_dot_p2p_dot_types__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_PEXREQUEST = _descriptor.Descriptor(
  name='PexRequest',
  full_name='tendermint.p2p.PexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=106,
)


_PEXADDRS = _descriptor.Descriptor(
  name='PexAddrs',
  full_name='tendermint.p2p.PexAddrs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='addrs', full_name='tendermint.p2p.PexAddrs.addrs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=108,
  serialized_end=167,
)


_MESSAGE = _descriptor.Descriptor(
  name='Message',
  full_name='tendermint.p2p.Message',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pex_request', full_name='tendermint.p2p.Message.pex_request', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pex_addrs', full_name='tendermint.p2p.Message.pex_addrs', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='tendermint.p2p.Message.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=169,
  serialized_end=283,
)

_PEXADDRS.fields_by_name['addrs'].message_type = tendermint_dot_p2p_dot_types__pb2._NETADDRESS
_MESSAGE.fields_by_name['pex_request'].message_type = _PEXREQUEST
_MESSAGE.fields_by_name['pex_addrs'].message_type = _PEXADDRS
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['pex_request'])
_MESSAGE.fields_by_name['pex_request'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
_MESSAGE.oneofs_by_name['sum'].fields.append(
  _MESSAGE.fields_by_name['pex_addrs'])
_MESSAGE.fields_by_name['pex_addrs'].containing_oneof = _MESSAGE.oneofs_by_name['sum']
DESCRIPTOR.message_types_by_name['PexRequest'] = _PEXREQUEST
DESCRIPTOR.message_types_by_name['PexAddrs'] = _PEXADDRS
DESCRIPTOR.message_types_by_name['Message'] = _MESSAGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PexRequest = _reflection.GeneratedProtocolMessageType('PexRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEXREQUEST,
  '__module__' : 'tendermint.p2p.pex_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.PexRequest)
  })
_sym_db.RegisterMessage(PexRequest)

PexAddrs = _reflection.GeneratedProtocolMessageType('PexAddrs', (_message.Message,), {
  'DESCRIPTOR' : _PEXADDRS,
  '__module__' : 'tendermint.p2p.pex_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.PexAddrs)
  })
_sym_db.RegisterMessage(PexAddrs)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'tendermint.p2p.pex_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.p2p.Message)
  })
_sym_db.RegisterMessage(Message)


DESCRIPTOR._options = None
_PEXADDRS.fields_by_name['addrs']._options = None
# @@protoc_insertion_point(module_scope)
